diff --git a/tencentcloud/cdb/v20170320/client.go b/tencentcloud/cdb/v20170320/client.go
index 6c4619e8..a9a9ae87 100644
--- a/tencentcloud/cdb/v20170320/client.go
+++ b/tencentcloud/cdb/v20170320/client.go
@@ -235,14 +235,14 @@ func NewCreateDBInstanceHourResponse() (response *CreateDBInstanceHourResponse)
return
}
-// This API is used to create a pay-as-you-go TencentDB instance (which can be a master, disaster recovery, or read-only instance) by passing in information such as instance specifications, MySQL version number, and quantity.
+// This API is used to create a pay-as-you-go TencentDB instance (which can be a main, disaster recovery, or read-only instance) by passing in information such as instance specifications, MySQL version number, and quantity.
//
// This is an async API. You can also use the [DescribeDBInstances](https://cloud.tencent.com/document/api/236/15872) API to query the instance details. If the `Status` value of an instance is 1 and `TaskStatus` is 0, the instance has been successfully delivered.
//
// 1. Please use the [DescribeDBZoneConfig](https://cloud.tencent.com/document/api/236/17229) API to query the supported instance specifications first and then use the [DescribeDBPrice](https://cloud.tencent.com/document/api/236/18566) API to query the prices of the supported instances;
// 2. You can create up to 100 instances at a time, with an instance validity period of up to 36 months;
// 3. MySQL v5.5, v5.6, and v5.7 are supported;
-// 4. Master instances, read-only instances, and disaster recovery instances can be created;
+// 4. Main instances, read-only instances, and disaster recovery instances can be created;
// 5. If `Port`, `ParamList`, or `Password` is set in the input parameters, the instance will be initialized.
func (c *Client) CreateDBInstanceHour(request *CreateDBInstanceHourRequest) (response *CreateDBInstanceHourResponse, err error) {
if request == nil {
@@ -872,7 +872,7 @@ func NewDescribeDBInstancesResponse() (response *DescribeDBInstancesResponse) {
return
}
-// This API (DescribeDBInstances) is used to query the list of TencentDB instances (which can be master, disaster recovery, or read-only instances). It supports filtering instances by project ID, instance ID, access address, and instance status.
+// This API (DescribeDBInstances) is used to query the list of TencentDB instances (which can be main, disaster recovery, or read-only instances). It supports filtering instances by project ID, instance ID, access address, and instance status.
func (c *Client) DescribeDBInstances(request *DescribeDBInstancesRequest) (response *DescribeDBInstancesResponse, err error) {
if request == nil {
request = NewDescribeDBInstancesRequest()
@@ -2084,7 +2084,7 @@ func NewRestartDBInstancesResponse() (response *RestartDBInstancesResponse) {
// This API (RestartDBInstances) is used to restart TencentDB instances.
//
// Note:
-// 1. This API only supports restarting master instances.
+// 1. This API only supports restarting main instances.
// 2. The instance status must be normal, and no other async tasks are in progress.
func (c *Client) RestartDBInstances(request *RestartDBInstancesRequest) (response *RestartDBInstancesResponse, err error) {
if request == nil {
@@ -2160,7 +2160,7 @@ func NewSwitchForUpgradeResponse() (response *SwitchForUpgradeResponse) {
return
}
-// This API (SwitchForUpgrade) is used to switch to a new instance. You can initiate this process when the master instance being upgraded is pending switch.
+// This API (SwitchForUpgrade) is used to switch to a new instance. You can initiate this process when the main instance being upgraded is pending switch.
func (c *Client) SwitchForUpgrade(request *SwitchForUpgradeRequest) (response *SwitchForUpgradeResponse, err error) {
if request == nil {
request = NewSwitchForUpgradeRequest()
@@ -2185,7 +2185,7 @@ func NewUpgradeDBInstanceResponse() (response *UpgradeDBInstanceResponse) {
return
}
-// This API is used to upgrade or downgrade a TencentDB instance, which can be a master instance, disaster recovery instance, or read-only instance.
+// This API is used to upgrade or downgrade a TencentDB instance, which can be a main instance, disaster recovery instance, or read-only instance.
func (c *Client) UpgradeDBInstance(request *UpgradeDBInstanceRequest) (response *UpgradeDBInstanceResponse, err error) {
if request == nil {
request = NewUpgradeDBInstanceRequest()
@@ -2210,7 +2210,7 @@ func NewUpgradeDBInstanceEngineVersionResponse() (response *UpgradeDBInstanceEng
return
}
-// This API (UpgradeDBInstanceEngineVersion) is used to upgrade the version of a TencentDB instance, which can be a master instance, disaster recovery instance, or read-only instance.
+// This API (UpgradeDBInstanceEngineVersion) is used to upgrade the version of a TencentDB instance, which can be a main instance, disaster recovery instance, or read-only instance.
func (c *Client) UpgradeDBInstanceEngineVersion(request *UpgradeDBInstanceEngineVersionRequest) (response *UpgradeDBInstanceEngineVersionResponse, err error) {
if request == nil {
request = NewUpgradeDBInstanceEngineVersionRequest()
diff --git a/tencentcloud/cdb/v20170320/models.go b/tencentcloud/cdb/v20170320/models.go
index 96d4c2bc..84d5bab8 100644
--- a/tencentcloud/cdb/v20170320/models.go
+++ b/tencentcloud/cdb/v20170320/models.go
@@ -144,16 +144,16 @@ func (r *AssociateSecurityGroupsResponse) FromJsonString(s string) error {
type BackupConfig struct {
- // Replication mode of slave database 2. Value range: async, semi-sync
+ // Replication mode of subordinate database 2. Value range: async, semi-sync
ReplicationMode *string `json:"ReplicationMode,omitempty" name:"ReplicationMode"`
- // Name of the AZ of slave database 2, such as ap-shanghai-1
+ // Name of the AZ of subordinate database 2, such as ap-shanghai-1
Zone *string `json:"Zone,omitempty" name:"Zone"`
- // Private IP address of slave database 2
+ // Private IP address of subordinate database 2
Vip *string `json:"Vip,omitempty" name:"Vip"`
- // Access port of slave database 2
+ // Access port of subordinate database 2
Vport *uint64 `json:"Vport,omitempty" name:"Vport"`
}
@@ -544,34 +544,34 @@ type CreateDBInstanceHourRequest struct {
// AZ information. By default, the system will automatically select an AZ. Please use the [DescribeDBZoneConfig](https://cloud.tencent.com/document/api/236/17229) API to query the supported AZs.
Zone *string `json:"Zone,omitempty" name:"Zone"`
- // Instance ID, which is required and the same as the master instance ID when purchasing read-only or disaster recovery instances. Please use the [DescribeDBInstances](https://cloud.tencent.com/document/api/236/15872) API to query the instance IDs.
- MasterInstanceId *string `json:"MasterInstanceId,omitempty" name:"MasterInstanceId"`
+ // Instance ID, which is required and the same as the main instance ID when purchasing read-only or disaster recovery instances. Please use the [DescribeDBInstances](https://cloud.tencent.com/document/api/236/15872) API to query the instance IDs.
+ MainInstanceId *string `json:"MainInstanceId,omitempty" name:"MainInstanceId"`
- // Instance type. Valid values: master (master instance), dr (disaster recovery instance), ro (read-only instance). Default value: master.
+ // Instance type. Valid values: main (main instance), dr (disaster recovery instance), ro (read-only instance). Default value: main.
InstanceRole *string `json:"InstanceRole,omitempty" name:"InstanceRole"`
- // AZ information of the master instance, which is required for purchasing disaster recovery instances.
- MasterRegion *string `json:"MasterRegion,omitempty" name:"MasterRegion"`
+ // AZ information of the main instance, which is required for purchasing disaster recovery instances.
+ MainRegion *string `json:"MainRegion,omitempty" name:"MainRegion"`
// Custom port. Value range: [1024-65535].
Port *int64 `json:"Port,omitempty" name:"Port"`
- // Sets the root account password. Rule: the password can contain 8–64 characters and must contain at least two of the following types of characters: letters, digits, and special symbols (_+-&=!@#$%^*()). This parameter can be specified when purchasing master instances and is meaningless for read-only or disaster recovery instances.
+ // Sets the root account password. Rule: the password can contain 8–64 characters and must contain at least two of the following types of characters: letters, digits, and special symbols (_+-&=!@#$%^*()). This parameter can be specified when purchasing main instances and is meaningless for read-only or disaster recovery instances.
Password *string `json:"Password,omitempty" name:"Password"`
// List of parameters in the format of `ParamList.0.Name=auto_increment&ParamList.0.Value=1`. You can use the [DescribeDefaultParams](https://cloud.tencent.com/document/api/236/32662) API to query the configurable parameters.
ParamList []*ParamInfo `json:"ParamList,omitempty" name:"ParamList" list`
- // Data replication mode. Valid values: 0 (async), 1 (semi-sync), 2 (strong sync). Default value: 0. This parameter can be specified when purchasing master instances and is meaningless for read-only or disaster recovery instances.
+ // Data replication mode. Valid values: 0 (async), 1 (semi-sync), 2 (strong sync). Default value: 0. This parameter can be specified when purchasing main instances and is meaningless for read-only or disaster recovery instances.
ProtectMode *int64 `json:"ProtectMode,omitempty" name:"ProtectMode"`
- // Multi-AZ. Valid value: 0 (single-AZ), 1 (multi-AZ). Default value: 0. This parameter can be specified when purchasing master instances and is meaningless for read-only or disaster recovery instances.
+ // Multi-AZ. Valid value: 0 (single-AZ), 1 (multi-AZ). Default value: 0. This parameter can be specified when purchasing main instances and is meaningless for read-only or disaster recovery instances.
DeployMode *int64 `json:"DeployMode,omitempty" name:"DeployMode"`
- // AZ information of slave database 1, which is the `Zone` value by default. This parameter can be specified when purchasing master instances and is meaningless for read-only or disaster recovery instances.
- SlaveZone *string `json:"SlaveZone,omitempty" name:"SlaveZone"`
+ // AZ information of subordinate database 1, which is the `Zone` value by default. This parameter can be specified when purchasing main instances and is meaningless for read-only or disaster recovery instances.
+ SubordinateZone *string `json:"SubordinateZone,omitempty" name:"SubordinateZone"`
- // AZ information of slave database 2, which is empty by default. This parameter can be specified when purchasing strong sync master instances and is meaningless for other types of instances.
+ // AZ information of subordinate database 2, which is empty by default. This parameter can be specified when purchasing strong sync main instances and is meaningless for other types of instances.
BackupZone *string `json:"BackupZone,omitempty" name:"BackupZone"`
// Security group parameter. You can use the [DescribeProjectSecurityGroups](https://cloud.tencent.com/document/api/236/15850) API to query the security group details of a project.
@@ -735,7 +735,7 @@ type DBSwitchInfo struct {
// Switch time in the format of yyyy-MM-dd HH:mm:ss, such as 2017-09-03 01:34:31
SwitchTime *string `json:"SwitchTime,omitempty" name:"SwitchTime"`
- // Switch type. Value range: TRANSFER (data migration), MASTER2SLAVE (master/slave switch), RECOVERY (master/slave recovery)
+ // Switch type. Value range: TRANSFER (data migration), MASTER2SLAVE (main/subordinate switch), RECOVERY (main/subordinate recovery)
SwitchType *string `json:"SwitchType,omitempty" name:"SwitchType"`
}
@@ -1604,19 +1604,19 @@ type DescribeDBInstanceConfigResponse struct {
*tchttp.BaseResponse
Response *struct {
- // Data protection mode of the master instance. Value range: 0 (async replication), 1 (semi-sync replication), 2 (strong sync replication).
+ // Data protection mode of the main instance. Value range: 0 (async replication), 1 (semi-sync replication), 2 (strong sync replication).
ProtectMode *int64 `json:"ProtectMode,omitempty" name:"ProtectMode"`
- // Master instance deployment mode. Value range: 0 (single-AZ), 1 (multi-AZ)
+ // Main instance deployment mode. Value range: 0 (single-AZ), 1 (multi-AZ)
DeployMode *int64 `json:"DeployMode,omitempty" name:"DeployMode"`
// Instance AZ information in the format of "ap-shanghai-1".
Zone *string `json:"Zone,omitempty" name:"Zone"`
- // Configuration information of the slave database.
- SlaveConfig *SlaveConfig `json:"SlaveConfig,omitempty" name:"SlaveConfig"`
+ // Configuration information of the subordinate database.
+ SubordinateConfig *SubordinateConfig `json:"SubordinateConfig,omitempty" name:"SubordinateConfig"`
- // Configuration information of slave database 2 of a strong sync instance.
+ // Configuration information of subordinate database 2 of a strong sync instance.
BackupConfig *BackupConfig `json:"BackupConfig,omitempty" name:"BackupConfig"`
// The unique request ID, which is returned for each request. RequestId is required for locating a problem.
@@ -1767,7 +1767,7 @@ type DescribeDBInstancesRequest struct {
// Project ID. You can use the [project list querying API](https://cloud.tencent.com/document/product/378/4400) to query the project ID.
ProjectId *int64 `json:"ProjectId,omitempty" name:"ProjectId"`
- // Instance type. Value range: 1 (master), 2 (disaster recovery), 3 (read-only).
+ // Instance type. Value range: 1 (main), 2 (disaster recovery), 3 (read-only).
InstanceTypes []*uint64 `json:"InstanceTypes,omitempty" name:"InstanceTypes" list`
// Private IP address of the instance.
@@ -1791,7 +1791,7 @@ type DescribeDBInstancesRequest struct {
// Instance name.
InstanceNames []*string `json:"InstanceNames,omitempty" name:"InstanceNames" list`
- // Instance task status. Value range:
0 - no task
1 - upgrading
2 - importing data
3 - activating slave
4 - public network access enabled
5 - batch operation in progress
6 - rolling back
7 - public network access not enabled
8 - modifying password
9 - renaming instance
10 - restarting
12 - migrating self-built instance
13 - dropping table
14 - creating and syncing disaster recovery instance
15 - pending upgrade and switch
16 - upgrade and switch in progress
17 - upgrade and switch completed
+ // Instance task status. Value range:
0 - no task
1 - upgrading
2 - importing data
3 - activating subordinate
4 - public network access enabled
5 - batch operation in progress
6 - rolling back
7 - public network access not enabled
8 - modifying password
9 - renaming instance
10 - restarting
12 - migrating self-built instance
13 - dropping table
14 - creating and syncing disaster recovery instance
15 - pending upgrade and switch
16 - upgrade and switch in progress
17 - upgrade and switch completed
TaskStatus []*uint64 `json:"TaskStatus,omitempty" name:"TaskStatus" list`
// Version of the instance database engine. Value range: 5.1, 5.5, 5.6, 5.7.
@@ -1830,14 +1830,14 @@ type DescribeDBInstancesRequest struct {
// Initialization flag. Value range: 0 (not initialized), 1 (initialized).
InitFlag *int64 `json:"InitFlag,omitempty" name:"InitFlag"`
- // Whether instances corresponding to the disaster recovery relationship are included. Valid values: 0 (not included), 1 (included). Default value: 1. If a master instance is pulled, the data of the disaster recovery relationship will be in the `DrInfo` field. If a disaster recovery instance is pulled, the data of the disaster recovery relationship will be in the `MasterInfo` field. The disaster recovery relationship contains only partial basic data. To get the detailed data, you need to call an API to pull it.
+ // Whether instances corresponding to the disaster recovery relationship are included. Valid values: 0 (not included), 1 (included). Default value: 1. If a main instance is pulled, the data of the disaster recovery relationship will be in the `DrInfo` field. If a disaster recovery instance is pulled, the data of the disaster recovery relationship will be in the `MainInfo` field. The disaster recovery relationship contains only partial basic data. To get the detailed data, you need to call an API to pull it.
WithDr *int64 `json:"WithDr,omitempty" name:"WithDr"`
// Whether read-only instances are included. Valid values: 0 (not included), 1 (included). Default value: 1.
WithRo *int64 `json:"WithRo,omitempty" name:"WithRo"`
- // Whether master instances are included. Valid values: 0 (not included), 1 (included). Default value: 1.
- WithMaster *int64 `json:"WithMaster,omitempty" name:"WithMaster"`
+ // Whether main instances are included. Valid values: 0 (not included), 1 (included). Default value: 1.
+ WithMain *int64 `json:"WithMain,omitempty" name:"WithMain"`
// Placement group ID list.
DeployGroupIds []*string `json:"DeployGroupIds,omitempty" name:"DeployGroupIds" list`
@@ -2908,7 +2908,7 @@ type DescribeTasksRequest struct {
// 8 - enabling GTID of a TencentDB instance;
// 9 - upgrading a read-only instance;
// 10 - rolling back databases in batches;
- // 11 - upgrading a master instance;
+ // 11 - upgrading a main instance;
// 12 - deleting a TencentDB table;
// 13 - promoting a disaster recovery instance.
TaskTypes []*int64 `json:"TaskTypes,omitempty" name:"TaskTypes" list`
@@ -3338,9 +3338,9 @@ type InstanceInfo struct {
// VPC ID, such as 51102
VpcId *int64 `json:"VpcId,omitempty" name:"VpcId"`
- // Information of a slave server
+ // Information of a subordinate server
// Note: This field may return null, indicating that no valid values can be obtained.
- SlaveInfo *SlaveInfo `json:"SlaveInfo,omitempty" name:"SlaveInfo"`
+ SubordinateInfo *SubordinateInfo `json:"SubordinateInfo,omitempty" name:"SubordinateInfo"`
// Instance ID
InstanceId *string `json:"InstanceId,omitempty" name:"InstanceId"`
@@ -3361,7 +3361,7 @@ type InstanceInfo struct {
// Subnet ID, such as 2333
SubnetId *int64 `json:"SubnetId,omitempty" name:"SubnetId"`
- // Instance type. Value range: 1 (master), 2 (disaster recovery), 3 (read-only)
+ // Instance type. Value range: 1 (main), 2 (disaster recovery), 3 (read-only)
InstanceType *int64 `json:"InstanceType,omitempty" name:"InstanceType"`
// Project ID
@@ -3376,12 +3376,12 @@ type InstanceInfo struct {
// AZ deployment mode. Valid values: 0 (single-AZ), 1 (multi-AZ)
DeployMode *int64 `json:"DeployMode,omitempty" name:"DeployMode"`
- // Instance task status. 0 - no task; 1 - upgrading; 2 - importing data; 3 - activating slave; 4 - enabling public network access; 5 - batch operation in progress; 6 - rolling back; 7 - disabling public network access; 8 - changing password; 9 - renaming instance; 10 - restarting; 12 - migrating self-built instance; 13 - dropping table; 14 - creating and syncing disaster recovery instance; 15 - pending upgrade and switch; 16 - upgrade and switch in progress; 17 - upgrade and switch completed
+ // Instance task status. 0 - no task; 1 - upgrading; 2 - importing data; 3 - activating subordinate; 4 - enabling public network access; 5 - batch operation in progress; 6 - rolling back; 7 - disabling public network access; 8 - changing password; 9 - renaming instance; 10 - restarting; 12 - migrating self-built instance; 13 - dropping table; 14 - creating and syncing disaster recovery instance; 15 - pending upgrade and switch; 16 - upgrade and switch in progress; 17 - upgrade and switch completed
TaskStatus *int64 `json:"TaskStatus,omitempty" name:"TaskStatus"`
- // Details of a master instance
+ // Details of a main instance
// Note: This field may return null, indicating that no valid values can be obtained.
- MasterInfo *MasterInfo `json:"MasterInfo,omitempty" name:"MasterInfo"`
+ MainInfo *MainInfo `json:"MainInfo,omitempty" name:"MainInfo"`
// Instance type. Value range: HA (High-Availability Edition), FE (Finance Edition), BASIC (Basic Edition)
DeviceType *string `json:"DeviceType,omitempty" name:"DeviceType"`
@@ -3510,7 +3510,7 @@ func (r *IsolateDBInstanceResponse) FromJsonString(s string) error {
return json.Unmarshal([]byte(s), &r)
}
-type MasterInfo struct {
+type MainInfo struct {
// Region information
Region *string `json:"Region,omitempty" name:"Region"`
@@ -4530,7 +4530,7 @@ type RoGroup struct {
// Read-only group name.
RoGroupName *string `json:"RoGroupName,omitempty" name:"RoGroupName"`
- // Whether to enable the function of isolating an instance that exceeds the latency threshold. If it is enabled, when the latency between the read-only instance and the master instance exceeds the latency threshold, the read-only instance will be isolated. Valid values: 1 (enabled), 0 (not enabled)
+ // Whether to enable the function of isolating an instance that exceeds the latency threshold. If it is enabled, when the latency between the read-only instance and the main instance exceeds the latency threshold, the read-only instance will be isolated. Valid values: 1 (enabled), 0 (not enabled)
RoOfflineDelay *int64 `json:"RoOfflineDelay,omitempty" name:"RoOfflineDelay"`
// Latency threshold
@@ -4591,8 +4591,8 @@ type RoGroupAttr struct {
type RoInstanceInfo struct {
- // Master instance ID corresponding to the RO group
- MasterInstanceId *string `json:"MasterInstanceId,omitempty" name:"MasterInstanceId"`
+ // Main instance ID corresponding to the RO group
+ MainInstanceId *string `json:"MainInstanceId,omitempty" name:"MainInstanceId"`
// RO instance status in the RO group. Value range: online, offline
RoStatus *string `json:"RoStatus,omitempty" name:"RoStatus"`
@@ -4615,7 +4615,7 @@ type RoInstanceInfo struct {
// RO instance status. Value range: 0 (creating), 1 (running), 4 (deleting)
Status *int64 `json:"Status,omitempty" name:"Status"`
- // Instance type. Value range: 1 (master), 2 (disaster recovery), 3 (read-only)
+ // Instance type. Value range: 1 (main), 2 (disaster recovery), 3 (read-only)
InstanceType *int64 `json:"InstanceType,omitempty" name:"InstanceType"`
// RO instance name
@@ -4624,7 +4624,7 @@ type RoInstanceInfo struct {
// Pay-as-you-go billing status. Value range: 1 (normal), 2 (in arrears)
HourFeeStatus *int64 `json:"HourFeeStatus,omitempty" name:"HourFeeStatus"`
- // RO instance task status. Value range:
0 - no task
1 - upgrading
2 - importing data
3 - activating slave
4 - public network access enabled
5 - batch operation in progress
6 - rolling back
7 - public network access not enabled
8 - modifying password
9 - renaming instance
10 - restarting
12 - migrating self-built instance
13 - dropping table
14 - creating and syncing disaster recovery instance
+ // RO instance task status. Value range:
0 - no task
1 - upgrading
2 - importing data
3 - activating subordinate
4 - public network access enabled
5 - batch operation in progress
6 - rolling back
7 - public network access not enabled
8 - modifying password
9 - renaming instance
10 - restarting
12 - migrating self-built instance
13 - dropping table
14 - creating and syncing disaster recovery instance
TaskStatus *int64 `json:"TaskStatus,omitempty" name:"TaskStatus"`
// RO instance memory size in MB
@@ -4854,26 +4854,26 @@ type SellType struct {
Configs []*SellConfig `json:"Configs,omitempty" name:"Configs" list`
}
-type SlaveConfig struct {
+type SubordinateConfig struct {
- // Replication mode of the slave database. Value range: async, semi-sync
+ // Replication mode of the subordinate database. Value range: async, semi-sync
ReplicationMode *string `json:"ReplicationMode,omitempty" name:"ReplicationMode"`
- // AZ name of the slave database, such as ap-shanghai-1
+ // AZ name of the subordinate database, such as ap-shanghai-1
Zone *string `json:"Zone,omitempty" name:"Zone"`
}
-type SlaveInfo struct {
+type SubordinateInfo struct {
- // Information of slave server 1
- First *SlaveInstanceInfo `json:"First,omitempty" name:"First"`
+ // Information of subordinate server 1
+ First *SubordinateInstanceInfo `json:"First,omitempty" name:"First"`
- // Information of slave server 2
+ // Information of subordinate server 2
// Note: This field may return null, indicating that no valid values can be obtained.
- Second *SlaveInstanceInfo `json:"Second,omitempty" name:"Second"`
+ Second *SubordinateInstanceInfo `json:"Second,omitempty" name:"Second"`
}
-type SlaveInstanceInfo struct {
+type SubordinateInstanceInfo struct {
// Port number
Vport *int64 `json:"Vport,omitempty" name:"Vport"`
@@ -5162,7 +5162,7 @@ type TaskDetail struct {
// "OPEN GTID" - enabling GTID of a TencentDB instance;
// "UPGRADE RO" - upgrading a read-only instance;
// "BATCH ROLLBACK" - rolling back databases in batches;
- // "UPGRADE MASTER" - upgrading a master instance;
+ // "UPGRADE MASTER" - upgrading a main instance;
// "DROP TABLES" - dropping a TencentDB table;
// "SWITCH DR TO MASTER" - promoting a disaster recovery instance.
TaskType *string `json:"TaskType,omitempty" name:"TaskType"`
@@ -5187,7 +5187,7 @@ type UpgradeDBInstanceEngineVersionRequest struct {
// Instance ID in the format of cdb-c1nl9rpv or cdbro-c1nl9rpv. It is the same as the instance ID displayed on the TencentDB Console page. You can use the [instance list querying API](https://cloud.tencent.com/document/api/236/15872) to query the ID, whose value is the `InstanceId` value in output parameters.
InstanceId *string `json:"InstanceId,omitempty" name:"InstanceId"`
- // Version of master instance database engine. Value range: 5.6, 5.7
+ // Version of main instance database engine. Value range: 5.6, 5.7
EngineVersion *string `json:"EngineVersion,omitempty" name:"EngineVersion"`
// Mode of switch to a new instance. Value range: 0 (switch immediately), 1 (switch within a time window). Default value: 0. If the value is 1, the switch process will be performed within a time window. Or, you can call the [switching to new instance API](https://cloud.tencent.com/document/product/236/15864) to trigger the process.
@@ -5236,25 +5236,25 @@ type UpgradeDBInstanceRequest struct {
// Disk size in GB after upgrade. To ensure that the `Volume` value to be passed in is valid, please use the [DescribeDBZoneConfig](https://cloud.tencent.com/document/product/236/17229) API to query the specifications of the disk that can be upgraded to.
Volume *int64 `json:"Volume,omitempty" name:"Volume"`
- // Data replication mode. Valid values: 0 (async), 1 (semi-sync), 2 (strong sync). This parameter can be specified when upgrading master instances and is meaningless for read-only or disaster recovery instances.
+ // Data replication mode. Valid values: 0 (async), 1 (semi-sync), 2 (strong sync). This parameter can be specified when upgrading main instances and is meaningless for read-only or disaster recovery instances.
ProtectMode *int64 `json:"ProtectMode,omitempty" name:"ProtectMode"`
- // Deployment mode. Valid values: 0 (single-AZ), 1 (multi-AZ). Default value: 0. This parameter can be specified when upgrading master instances and is meaningless for read-only or disaster recovery instances.
+ // Deployment mode. Valid values: 0 (single-AZ), 1 (multi-AZ). Default value: 0. This parameter can be specified when upgrading main instances and is meaningless for read-only or disaster recovery instances.
DeployMode *int64 `json:"DeployMode,omitempty" name:"DeployMode"`
- // AZ information of slave database 1, which is the `Zone` value of the instance by default. This parameter can be specified when upgrading master instances in multi-AZ mode and is meaningless for read-only or disaster recovery instances. You can use the [DescribeDBZoneConfig](https://cloud.tencent.com/document/product/236/17229) API to query the supported AZs.
- SlaveZone *string `json:"SlaveZone,omitempty" name:"SlaveZone"`
+ // AZ information of subordinate database 1, which is the `Zone` value of the instance by default. This parameter can be specified when upgrading main instances in multi-AZ mode and is meaningless for read-only or disaster recovery instances. You can use the [DescribeDBZoneConfig](https://cloud.tencent.com/document/product/236/17229) API to query the supported AZs.
+ SubordinateZone *string `json:"SubordinateZone,omitempty" name:"SubordinateZone"`
- // Version of master instance database engine. Valid values: 5.5, 5.6, 5.7.
+ // Version of main instance database engine. Valid values: 5.5, 5.6, 5.7.
EngineVersion *string `json:"EngineVersion,omitempty" name:"EngineVersion"`
// Mode of switch to new instance. Valid values: 0 (switch immediately), 1 (switch within a time window). Default value: 0. If the value is 1, the switch process will be performed within a time window. Or, you can call the [SwitchForUpgrade](https://cloud.tencent.com/document/product/236/15864) API to trigger the process.
WaitSwitch *int64 `json:"WaitSwitch,omitempty" name:"WaitSwitch"`
- // AZ information of slave database 2, which is empty by default. This parameter can be specified when upgrading master instances and is meaningless for read-only or disaster recovery instances.
+ // AZ information of subordinate database 2, which is empty by default. This parameter can be specified when upgrading main instances and is meaningless for read-only or disaster recovery instances.
BackupZone *string `json:"BackupZone,omitempty" name:"BackupZone"`
- // Instance type. Valid values: master (master instance), dr (disaster recovery instance), ro (read-only instance). Default value: master.
+ // Instance type. Valid values: main (main instance), dr (disaster recovery instance), ro (read-only instance). Default value: main.
InstanceRole *string `json:"InstanceRole,omitempty" name:"InstanceRole"`
}
@@ -5305,11 +5305,11 @@ type ZoneConf struct {
// AZ deployment mode. Value range: 0 (single-AZ), 1 (multi-AZ)
DeployMode []*int64 `json:"DeployMode,omitempty" name:"DeployMode" list`
- // AZ where the master instance is located
- MasterZone []*string `json:"MasterZone,omitempty" name:"MasterZone" list`
+ // AZ where the main instance is located
+ MainZone []*string `json:"MainZone,omitempty" name:"MainZone" list`
// AZ where salve database 1 is located when the instance is deployed in multi-AZ mode
- SlaveZone []*string `json:"SlaveZone,omitempty" name:"SlaveZone" list`
+ SubordinateZone []*string `json:"SubordinateZone,omitempty" name:"SubordinateZone" list`
// AZ where salve database 2 is located when the instance is deployed in multi-AZ mode
BackupZone []*string `json:"BackupZone,omitempty" name:"BackupZone" list`
diff --git a/tencentcloud/cdn/v20180606/models.go b/tencentcloud/cdn/v20180606/models.go
index b31e4c74..ebdb90f7 100644
--- a/tencentcloud/cdn/v20180606/models.go
+++ b/tencentcloud/cdn/v20180606/models.go
@@ -2183,13 +2183,13 @@ type DomainAreaConfig struct {
type DomainFilter struct {
// Filter field name, the list supported is as follows:
- // - origin: master origin server.
+ // - origin: main origin server.
// - domain: domain name.
// - resourceId: domain name id.
// - status: domain name status. Values include `online`, `offline`, or `processing`.
// - serviceType: service type. Values include `web`, `download`, or `media`.
// - projectId: project ID.
- // - domainType: master origin server type, `cname` indicates external origin, `COS` indicates COS origin.
+ // - domainType: main origin server type, `cname` indicates external origin, `COS` indicates COS origin.
// - fullUrlCache: full-path cache, which can be on or off.
// - https: whether to configure HTTPS, which can be on, off or processing.
// - originPullProtocol: origin-pull protocol type. HTTP, follow, or HTTPS are supported.
@@ -3041,12 +3041,12 @@ type MaxAgeRule struct {
type Origin struct {
- // Master origin server list
+ // Main origin server list
// When modifying the origin server, you need to enter the corresponding OriginType.
// Note: this field may return null, indicating that no valid values can be obtained.
Origins []*string `json:"Origins,omitempty" name:"Origins" list`
- // Master origin server type
+ // Main origin server type
// The following types are supported for input parameters:
// domain: domain name type
// cos: COS origin
@@ -3061,7 +3061,7 @@ type Origin struct {
// Note: this field may return null, indicating that no valid values can be obtained.
OriginType *string `json:"OriginType,omitempty" name:"OriginType"`
- // Host header used when accessing the master origin server. If left empty, the acceleration domain name will be used by default.
+ // Host header used when accessing the main origin server. If left empty, the acceleration domain name will be used by default.
// If a wildcard domain name is accessed, then the sub-domain name during the access will be used by default.
// Note: this field may return null, indicating that no valid values can be obtained.
ServerName *string `json:"ServerName,omitempty" name:"ServerName"`
@@ -3090,7 +3090,7 @@ type Origin struct {
// Note: this field may return null, indicating that no valid values can be obtained.
BackupOriginType *string `json:"BackupOriginType,omitempty" name:"BackupOriginType"`
- // Host header used when accessing the backup origin server. If left empty, the ServerName of master origin server will be used by default.
+ // Host header used when accessing the backup origin server. If left empty, the ServerName of main origin server will be used by default.
// Note: this field may return null, indicating that no valid values can be obtained.
BackupServerName *string `json:"BackupServerName,omitempty" name:"BackupServerName"`
diff --git a/tencentcloud/dcdb/v20180411/models.go b/tencentcloud/dcdb/v20180411/models.go
index f6c401aa..47a9f0fa 100644
--- a/tencentcloud/dcdb/v20180411/models.go
+++ b/tencentcloud/dcdb/v20180411/models.go
@@ -188,13 +188,13 @@ type CreateAccountRequest struct {
// Account password, which can contain 6–32 letters, digits, and common symbols but not semicolons, single quotation marks, and double quotation marks.
Password *string `json:"Password,omitempty" name:"Password"`
// Whether to create a read-only account. 0: no; 1: for the account's SQL requests, the slave will be used first, and if it is unavailable, the master will be used; 2: the slave will be used first, and if it is unavailable, the operation will fail; 3: only the slave will be read from.
ReadOnly *int64 `json:"ReadOnly,omitempty" name:"ReadOnly"`
// Account remarks, which can contain 0–256 letters, digits, and common symbols.
Description *string `json:"Description,omitempty" name:"Description"`
// If the slave delay exceeds the set value of this parameter, the slave will be deemed to have failed.
// It is recommended that this parameter be set to a value greater than 10. This parameter takes effect when `ReadOnly` is 1 or 2.
DelayThresh *int64 `json:"DelayThresh,omitempty" name:"DelayThresh"`
}
@@ -255,10 +255,10 @@ type DBAccount struct {
// Last updated time
UpdateTime *string `json:"UpdateTime,omitempty" name:"UpdateTime"`
// Read-only flag. 0: no; 1: for the account's SQL requests, the slave will be used first, and if it is unavailable, the master will be used; 2: the slave will be used first, and if it is unavailable, the operation will fail.
ReadOnly *int64 `json:"ReadOnly,omitempty" name:"ReadOnly"`
// If the slave delay exceeds the set value of this parameter, the slave will be deemed to have failed.
// It is recommended that this parameter be set to a value greater than 10. This parameter takes effect when `ReadOnly` is 1 or 2.
DelayThresh *int64 `json:"DelayThresh,omitempty" name:"DelayThresh"`
}
@@ -337,7 +337,7 @@ type DCDBInstanceInfo struct {
// Shard details
ShardDetail []*ShardInfo `json:"ShardDetail,omitempty" name:"ShardDetail" list`
// Number of nodes. 2: one master and one slave; 3: one master and two slaves
NodeCount *int64 `json:"NodeCount,omitempty" name:"NodeCount"`
// Temporary instance flag. 0: non-temporary instance
@@ -437,7 +437,7 @@ type DCDBShardInfo struct {
// Expiration time
PeriodEndTime *string `json:"PeriodEndTime,omitempty" name:"PeriodEndTime"`
// Number of nodes. 2: one master and one slave; 3: one master and two slaves
NodeCount *int64 `json:"NodeCount,omitempty" name:"NodeCount"`
// Storage utilization in %
@@ -459,13 +459,13 @@ type DCDBShardInfo struct {
// Note: this field may return null, indicating that no valid values can be obtained.
Paymode *string `json:"Paymode,omitempty" name:"Paymode"`
// Master AZ of a shard
// Note: this field may return null, indicating that no valid values can be obtained.
- ShardMasterZone *string `json:"ShardMasterZone,omitempty" name:"ShardMasterZone"`
+ ShardMainZone *string `json:"ShardMainZone,omitempty" name:"ShardMainZone"`
- // List of slave AZs of a shard
+ // List of subordinate AZs of a shard
// Note: this field may return null, indicating that no valid values can be obtained.
- ShardSlaveZones []*string `json:"ShardSlaveZones,omitempty" name:"ShardSlaveZones" list`
+ ShardSubordinateZones []*string `json:"ShardSubordinateZones,omitempty" name:"ShardSubordinateZones" list`
// Number of CPU cores
Cpu *int64 `json:"Cpu,omitempty" name:"Cpu"`
@@ -1571,7 +1571,7 @@ type ShardInfo struct {
// Numeric ID of a shard
ShardId *int64 `json:"ShardId,omitempty" name:"ShardId"`
// Number of nodes. 2: one master and one slave; 3: one master and two slaves
NodeCount *int64 `json:"NodeCount,omitempty" name:"NodeCount"`
// Product type ID (this field is obsolete and should not be depended on)
@@ -188,13 +188,13 @@ type CreateAccountRequest struct {
// Account password, which can contain 6–32 letters, digits, and common symbols but not semicolons, single quotation marks, and double quotation marks.
Password *string `json:"Password,omitempty" name:"Password"`
- // Whether to create a read-only account. 0: no; 1: for the account's SQL requests, the slave will be used first, and if it is unavailable, the master will be used; 2: the slave will be used first, and if it is unavailable, the operation will fail; 3: only the slave will be read from.
+ // Whether to create a read-only account. 0: no; 1: for the account's SQL requests, the subordinate will be used first, and if it is unavailable, the main will be used; 2: the subordinate will be used first, and if it is unavailable, the operation will fail; 3: only the subordinate will be read from.
ReadOnly *int64 `json:"ReadOnly,omitempty" name:"ReadOnly"`
// Account remarks, which can contain 0–256 letters, digits, and common symbols.
@@ -188,13 +188,13 @@ type CreateAccountRequest struct {
// Account remarks, which can contain 0–256 letters, digits, and common symbols.
Description *string `json:"Description,omitempty" name:"Description"`
- // If the slave delay exceeds the set value of this parameter, the slave will be deemed to have failed.
+ // If the subordinate delay exceeds the set value of this parameter, the subordinate will be deemed to have failed.
// It is recommended that this parameter be set to a value greater than 10. This parameter takes effect when `ReadOnly` is 1 or 2.
DelayThresh *int64 `json:"DelayThresh,omitempty" name:"DelayThresh"`
@@ -255,10 +255,10 @@ type DBAccount struct {
// Last updated time
UpdateTime *string `json:"UpdateTime,omitempty" name:"UpdateTime"`
- // Read-only flag. 0: no; 1: for the account's SQL requests, the slave will be used first, and if it is unavailable, the master will be used; 2: the slave will be used first, and if it is unavailable, the operation will fail.
+ // Read-only flag. 0: no; 1: for the account's SQL requests, the subordinate will be used first, and if it is unavailable, the main will be used; 2: the subordinate will be used first, and if it is unavailable, the operation will fail.
ReadOnly *int64 `json:"ReadOnly,omitempty" name:"ReadOnly"`
@@ -255,10 +255,10 @@ type DBAccount struct {
ReadOnly *int64 `json:"ReadOnly,omitempty" name:"ReadOnly"`
- // If the slave delay exceeds the set value of this parameter, the slave will be deemed to have failed.
+ // If the subordinate delay exceeds the set value of this parameter, the subordinate will be deemed to have failed.
// It is recommended that this parameter be set to a value greater than 10. This parameter takes effect when `ReadOnly` is 1 or 2.
DelayThresh *int64 `json:"DelayThresh,omitempty" name:"DelayThresh"`
@@ -337,7 +337,7 @@ type DCDBInstanceInfo struct {
// Shard details
ShardDetail []*ShardInfo `json:"ShardDetail,omitempty" name:"ShardDetail" list`
- // Number of nodes. 2: one master and one slave; 3: one master and two slaves
+ // Number of nodes. 2: one main and one subordinate; 3: one main and two subordinates
NodeCount *int64 `json:"NodeCount,omitempty" name:"NodeCount"`
// Temporary instance flag. 0: non-temporary instance
@@ -437,7 +437,7 @@ type DCDBShardInfo struct {
// Expiration time
PeriodEndTime *string `json:"PeriodEndTime,omitempty" name:"PeriodEndTime"`
- // Number of nodes. 2: one master and one slave; 3: one master and two slaves
+ // Number of nodes. 2: one main and one subordinate; 3: one main and two subordinates
NodeCount *int64 `json:"NodeCount,omitempty" name:"NodeCount"`
// Storage utilization in %
@@ -459,13 +459,13 @@ type DCDBShardInfo struct {
// Note: this field may return null, indicating that no valid values can be obtained.
Paymode *string `json:"Paymode,omitempty" name:"Paymode"`
- // Master AZ of a shard
+ // Main AZ of a shard
// Note: this field may return null, indicating that no valid values can be obtained.
@@ -1571,7 +1571,7 @@ type ShardInfo struct {
// Numeric ID of a shard
ShardId *int64 `json:"ShardId,omitempty" name:"ShardId"`
- // Number of nodes. 2: one master and one slave; 3: one master and two slaves
+ // Number of nodes. 2: one main and one subordinate; 3: one main and two subordinates
NodeCount *int64 `json:"NodeCount,omitempty" name:"NodeCount"`
// Product type ID (this field is obsolete and should not be depended on)
diff --git a/tencentcloud/dts/v20180330/client.go b/tencentcloud/dts/v20180330/client.go
index aa81efc0..d029aa4f 100644
--- a/tencentcloud/dts/v20180330/client.go
+++ b/tencentcloud/dts/v20180330/client.go
@@ -791,27 +791,27 @@ func (c *Client) StopMigrateJob(request *StopMigrateJobRequest) (response *StopM
return
}
-func NewSwitchDrToMasterRequest() (request *SwitchDrToMasterRequest) {
- request = &SwitchDrToMasterRequest{
+func NewSwitchDrToMainRequest() (request *SwitchDrToMainRequest) {
+ request = &SwitchDrToMainRequest{
BaseRequest: &tchttp.BaseRequest{},
}
- request.Init().WithApiInfo("dts", APIVersion, "SwitchDrToMaster")
+ request.Init().WithApiInfo("dts", APIVersion, "SwitchDrToMain")
return
}
-func NewSwitchDrToMasterResponse() (response *SwitchDrToMasterResponse) {
- response = &SwitchDrToMasterResponse{
+func NewSwitchDrToMainResponse() (response *SwitchDrToMainResponse) {
+ response = &SwitchDrToMainResponse{
BaseResponse: &tchttp.BaseResponse{},
}
return
}
-// This API is used to promote a disaster recovery instance to a master instance, which will stop sync from the original master instance and end the master/slave relationship.
-func (c *Client) SwitchDrToMaster(request *SwitchDrToMasterRequest) (response *SwitchDrToMasterResponse, err error) {
+// This API is used to promote a disaster recovery instance to a main instance, which will stop sync from the original main instance and end the main/subordinate relationship.
+func (c *Client) SwitchDrToMain(request *SwitchDrToMainRequest) (response *SwitchDrToMainResponse, err error) {
if request == nil {
- request = NewSwitchDrToMasterRequest()
+ request = NewSwitchDrToMainRequest()
}
- response = NewSwitchDrToMasterResponse()
+ response = NewSwitchDrToMainResponse()
err = c.Send(request, response)
return
}
diff --git a/tencentcloud/dts/v20180330/models.go b/tencentcloud/dts/v20180330/models.go
index 43bd95b4..e36ce587 100644
--- a/tencentcloud/dts/v20180330/models.go
+++ b/tencentcloud/dts/v20180330/models.go
@@ -978,11 +978,11 @@ type MigrateDetailInfo struct {
// Progress of current step, such as "1"
CurrentStepProgress *string `json:"CurrentStepProgress,omitempty" name:"CurrentStepProgress"`
- // Master/slave lag in MB, which is valid during incremental sync and currently supported by TencentDB for Redis and MySQL
- MasterSlaveDistance *int64 `json:"MasterSlaveDistance,omitempty" name:"MasterSlaveDistance"`
+ // Main/subordinate lag in MB, which is valid during incremental sync and currently supported by TencentDB for Redis and MySQL
+ MainSubordinateDistance *int64 `json:"MainSubordinateDistance,omitempty" name:"MainSubordinateDistance"`
- // Master/slave lag in seconds, which is valid during incremental sync and currently supported by TencentDB for MySQL
- SecondsBehindMaster *int64 `json:"SecondsBehindMaster,omitempty" name:"SecondsBehindMaster"`
+ // Main/subordinate lag in seconds, which is valid during incremental sync and currently supported by TencentDB for MySQL
+ SecondsBehindMain *int64 `json:"SecondsBehindMain,omitempty" name:"SecondsBehindMain"`
// Step information
StepInfo []*MigrateStepDetailInfo `json:"StepInfo,omitempty" name:"StepInfo" list`
@@ -1062,9 +1062,9 @@ type MigrateOption struct {
// Additional parameters for different databases, which are described in JSON format.
// The following parameters can be defined for Redis:
// {
// "ClientOutputBufferHardLimit":512, Hard capacity limit of slave buffer (MB)
// "ClientOutputBufferSoftLimit":512, Soft capacity limit of slave buffer (MB)
// "ClientOutputBufferPersistTime":60, Soft limit duration of slave buffer (s)
// "ReplBacklogSize":512, Circular buffer capacity limit (MB)
// "ReplTimeout":120, Replication timeout period (s)
// }
@@ -1693,7 +1693,7 @@ type SubscribeRegionConf struct {
Status *int64 `json:"Status,omitempty" name:"Status"`
}
-type SwitchDrToMasterRequest struct {
+type SwitchDrToMainRequest struct {
*tchttp.BaseRequest
// Disaster recovery instance information
@@ -1703,16 +1703,16 @@ type SwitchDrToMasterRequest struct {
DatabaseType *string `json:"DatabaseType,omitempty" name:"DatabaseType"`
}
-func (r *SwitchDrToMasterRequest) ToJsonString() string {
+func (r *SwitchDrToMainRequest) ToJsonString() string {
b, _ := json.Marshal(r)
return string(b)
}
-func (r *SwitchDrToMasterRequest) FromJsonString(s string) error {
+func (r *SwitchDrToMainRequest) FromJsonString(s string) error {
return json.Unmarshal([]byte(s), &r)
}
-type SwitchDrToMasterResponse struct {
+type SwitchDrToMainResponse struct {
*tchttp.BaseResponse
Response *struct {
@@ -1724,12 +1724,12 @@ type SwitchDrToMasterResponse struct {
} `json:"Response"`
}
-func (r *SwitchDrToMasterResponse) ToJsonString() string {
+func (r *SwitchDrToMainResponse) ToJsonString() string {
b, _ := json.Marshal(r)
return string(b)
}
-func (r *SwitchDrToMasterResponse) FromJsonString(s string) error {
+func (r *SwitchDrToMainResponse) FromJsonString(s string) error {
return json.Unmarshal([]byte(s), &r)
}
@@ -1762,11 +1762,11 @@ type SyncDetailInfo struct {
// Progress of the current step
CurrentStepProgress *string `json:"CurrentStepProgress,omitempty" name:"CurrentStepProgress"`
- // Master/slave delay in MB
- MasterSlaveDistance *int64 `json:"MasterSlaveDistance,omitempty" name:"MasterSlaveDistance"`
+ // Main/subordinate delay in MB
+ MainSubordinateDistance *int64 `json:"MainSubordinateDistance,omitempty" name:"MainSubordinateDistance"`
- // Master/slave delay in seconds
- SecondsBehindMaster *int64 `json:"SecondsBehindMaster,omitempty" name:"SecondsBehindMaster"`
+ // Main/subordinate delay in seconds
+ SecondsBehindMain *int64 `json:"SecondsBehindMain,omitempty" name:"SecondsBehindMain"`
// Step information
StepInfo []*SyncStepDetailInfo `json:"StepInfo,omitempty" name:"StepInfo" list`
@@ -1062,9 +1062,9 @@ type MigrateOption struct {
// The following parameters can be defined for Redis:
// {
- // "ClientOutputBufferHardLimit":512, Hard capacity limit of slave buffer (MB)
- // "ClientOutputBufferSoftLimit":512, Soft capacity limit of slave buffer (MB)
- // "ClientOutputBufferPersistTime":60, Soft limit duration of slave buffer (s)
+ // "ClientOutputBufferHardLimit":512, Hard capacity limit of subordinate buffer (MB)
+ // "ClientOutputBufferSoftLimit":512, Soft capacity limit of subordinate buffer (MB)
+ // "ClientOutputBufferPersistTime":60, Soft limit duration of subordinate buffer (s)
// "ReplBacklogSize":512, Circular buffer capacity limit (MB)
// "ReplTimeout":120, Replication timeout period (s)
diff --git a/tencentcloud/emr/v20190103/models.go b/tencentcloud/emr/v20190103/models.go
index 1080f91a..e7dd9ff7 100644
--- a/tencentcloud/emr/v20190103/models.go
+++ b/tencentcloud/emr/v20190103/models.go
@@ -184,9 +184,9 @@ type ClusterInstancesInfo struct {
// Note: this field may return null, indicating that no valid values can be obtained.
Config *EmrProductConfigOutter `json:"Config,omitempty" name:"Config"`
// Public IP of master node
// Note: this field may return null, indicating that no valid values can be obtained.
- MasterIp *string `json:"MasterIp,omitempty" name:"MasterIp"`
+ MainIp *string `json:"MainIp,omitempty" name:"MainIp"`
// EMR version
// Note: this field may return null, indicating that no valid values can be obtained.
@@ -313,10 +313,10 @@ type CreateInstanceRequest struct {
// Client token.
ClientToken *string `json:"ClientToken,omitempty" name:"ClientToken"`
- // Whether to enable public IP access for master node. Valid values:
- //
@@ -184,9 +184,9 @@ type ClusterInstancesInfo struct {
// Note: this field may return null, indicating that no valid values can be obtained.
Config *EmrProductConfigOutter `json:"Config,omitempty" name:"Config"`
- // Public IP of master node
+ // Public IP of main node
// Note: this field may return null, indicating that no valid values can be obtained.